

import QtQuick 2.0
import Sailfish.Silica 1.0
import QtQuick.XmlListModel 2.0

Page {

    property string message: ""

    id: netflixSinglePage

    XmlListModel {
        id: singleEvents
        source: "http://www.omdbapi.com/?t=" + message + "&r=XML"
        query: "/root/movie"
        XmlRole {
            name: "title"
            query: "@title/string()"
        }
        XmlRole {
            name: "runtime"
            query: "@runtime/string()"
        }
        XmlRole {
            name: "genre"
            query: "@genre/string()"
        }

        XmlRole {
            name: "plot"
            query: "@plot/string()"
        }
        XmlRole {
            name: "poster"
            query: "@poster/string()"
        }
        XmlRole {
            name: "imdbRating"
            query: "@imdbRating/string()"
        }

        onStatusChanged: {

            if (status === XmlListModel.Ready) {
                var tempPoster = get(0).poster
                if(tempPoster === "N/A"){
                    tempPoster="noposter.png"
                }
                titleLabel.text = get(0).title
                ratingLabel.text = "IMDB: " + get(0).imdbRating
                runtimeLabel.text ="Runtime: " + get(0).runtime
                genreLabel.text = "Genre: " + get(0).genre
                poster.source = tempPoster
                synopsisLabel.text = get(0).plot

            }
        }
    }


    SilicaFlickable {

        anchors.fill:parent

        PullDownMenu {
            MenuItem {
                text: "Finnkino"
                onClicked: {
                    pageStack.clear()
                    pageStack.push(Qt.resolvedUrl("MenuPage.qml"))
                    pageStack.push(Qt.resolvedUrl("Finnkinopage.qml"))
                }
            }
            MenuItem {
                text: "Netflix"
                onClicked: {
                    pageStack.clear()
                    pageStack.push(Qt.resolvedUrl("MenuPage.qml"))
                    pageStack.push(Qt.resolvedUrl("NetflixPage.qml"))
                }
            }
            MenuItem {
                text: "Bluray"
                onClicked: {
                    pageStack.clear()
                    pageStack.push(Qt.resolvedUrl("MenuPage.qml"))
                    pageStack.push(Qt.resolvedUrl("BluRayPage.qml"))
                }
            }
        }

        PageHeader {
            title: "Film"
        }

        Column {
            id:labelContainer
            spacing: 5
            width:parent.width
            anchors.top:parent.top
            anchors.topMargin: 75

            Label {
                width: parent.width
                id:titleLabel
                text: ""
                x: Theme.paddingLarge
                font { pixelSize: Theme.fontSizeExtraLarge }
                wrapMode: Text.WordWrap
                maximumLineCount: 4
                truncationMode: TruncationMode.Fade
            }

            Row {
                spacing: 2
                // first label to move image from left corner
                Label {text:"   "}
                Image {
                    id:poster
                    height: Theme.itemSizeExtraLarge + 150
                    width: Theme.itemSizeExtraLarge + 50
                    source: ""
                }

                Column {
                    Label {
                        id:ratingLabel
                        text: ""
                        x: Theme.paddingLarge
                        font { pixelSize: Theme.fontSizeLarge }
                    }
                    Label {
                        id:runtimeLabel
                        text: ""
                        x: Theme.paddingLarge
                        font { pixelSize: Theme.fontSizeLarge }
                    }
                    Label {
                        id:genreLabel
                        text: ""
                        x: Theme.paddingLarge
                        width: 300
                        font { pixelSize: Theme.fontSizeLarge }
                        wrapMode: Text.WordWrap
                        maximumLineCount: 3
                        truncationMode: TruncationMode.Fade

                    }
                }
            }

            // Pädding
            Label {
                text:" "
            }

            Label {
                width: parent.width
                id:synopsisLabel
                text: ""
                x: Theme.paddingSmall
                font.pixelSize: Theme.fontSizeMedium
                wrapMode: Text.WordWrap
                maximumLineCount: 20
                truncationMode: TruncationMode.Fade

            }
        }
    }
}
